<?php

namespace App\Wrangler\Components;

use Illuminate\Http\Request;
use Medialight\Textstem\Helpers\MediaAsset;
use Medialight\Textstem\Models\WranglerPage;
use Medialight\Textstem\Wrangler\ActiveComponent;

class Card extends ActiveComponent
{
    public static string $description = 'Displays some html in a card or well.';

    public $config;

    public array $editSetup = [
        [
            'name' => 'title',
            'controltype' => 'text',
            'value' => '',
            'label' => 'Title',
            'instructions' => 'Optional title. Note - this text will be escaped. To enter raw HTML, use the HTML block.',
        ],
        [
            'name' => 'content',
            'controltype' => 'richtext',
            'value' => '',
            'label' => 'Content',
        ],
        [
            'name' => 'image',
            'controltype' => 'image',
            'value' => '',
            'label' => "Image (Desktop)",
            'aspect' => '16/6',
            'size' => 3
        ],
        [
            'name' => 'imagemobile',
            'controltype' => 'image',
            'value' => '',
            'label' => "Image (Mobile)",
            'aspect' => 'square',
            'size' => 1
        ],
        [
            'name' => 'width',
            'controltype' => 'select',
            'value' => 'full',
            'options' => [
                '12' => 'full',
                '6' => '1/2',
                '4' => '1/3',
                '3' => '1/4'
            ],
            'label' => 'Width',
            'size' => 1
        ],
        [
            'name' => 'width_sm',
            'controltype' => 'select',
            'value' => '1/2',
            'options' => [
                '12' => 'full',
                '6' => '1/2',
                '4' => '1/3',
                '3' => '1/4'
            ],
            'label' => 'Width (tablet)',
            'size' => 1
        ],
        [
            'name' => 'width_md',
            'controltype' => 'select',
            'value' => '1/3',
            'options' => [
                '12' => 'full',
                '6' => '1/2',
                '4' => '1/3',
                '3' => '1/4'
            ],
            'label' => 'Width (laptop)',
            'size' => 1
        ],
        [
            'name' => 'width_lg',
            'controltype' => 'select',
            'value' => '1/4',
            'options' => [
                '12' => 'full',
                '6' => '1/2',
                '4' => '1/3',
                '3' => '1/4'
            ],
            'label' => 'Width (desktop)',
            'size' => 1
        ],
        [
            'name' => 'link',
            'controltype' => 'text',
            'value' => '',
            'label' => 'Link',
            'size' => 4
        ],
//        [
//            'name' => 'link2',
//            'controltype' => 'text',
//            'value' => '',
//            'label' => 'Secondary Link',
//            'size' =>2
//        ],
        [
            'name' => 'template',
            'controltype' => 'select-template',
            'value' => 'default',
        ],
    ];

    public function render(Request $request, WranglerPage $wranglerPage)
    {
        $view = $this->getView();
        $viewData = $this->data();

        $viewData['asset'] = MediaAsset::loadForPath($this->config['image'] ?? '');
        $viewData['assetmobile'] = MediaAsset::loadForPath($this->config['imagemobile'] ?? ($this->config['content'] ?? ''));

        return view($view, $viewData)->render();
    }

    public function preview()
    {
        $view = $this->getView();
        $viewData = $this->data();
        $viewData['asset'] = MediaAsset::loadForPath($this->config['image'] ?? '');
        $viewData['assetmobile'] = MediaAsset::loadForPath($this->config['imagemobile'] ?? ($this->config['content'] ?? ''));
        return view($view, $viewData)->render();
    }





}
